 Repositório com desenvolvimento dos códigos, e arquivos, para entrega do Projeto do Curso de Python para Cientistas de dados: Criação de Pacotes de Processamento de Imagens; da plataforma [DIO - Digital Innovation One](https://web.dio.me/).  
#
# Processamento de Imagens

Descrição: 

O pacote '**processamento_de_imagem**' pode ser usado para:

	Processamento:
		- Correspondência de Histograma;
		- Similaridade Estrutural;
		- Redimensionamento de Tamanhos
	
	Utilitários:
		- Leitor de Imagem;
		- Salvador de Imagem;
		- Exibidor de Imagens;
		- Exibidor de Resultados;
		- Exibidor de Histograma

## Instalação:

Use o gerenciador de pacotes [pip](https://pip.pypa.io/en/stable/) para instalação do pacote '**processamento_de_imagem**':

```bash
pip install processamento_de_imagens
```

## Uso:

```python
from package_name.module1_name import file1_name
file1_name.my_function()
```
 Repositório com desenvolvimento dos códigos, e arquivos, para entrega do Projeto do Curso de Python para Cientistas de dados: Criação de Pacotes de Processamento de Imagens; da plataforma [DIO - Digital Innovation One](https://web.dio.me/).  
#
# Processamento de Imagens

Descrição: 

O pacote '**processamento_de_imagem**' pode ser usado para:

	Processamento:
		- Correspondência de Histograma;
		- Similaridade Estrutural;
		- Redimensionamento de Tamanhos
	
	Utilitários:
		- Leitor de Imagem;
		- Salvador de Imagem;
		- Exibidor de Imagens;
		- Exibidor de Resultados;
		- Exibidor de Histograma

## Instalação:

Use o gerenciador de pacotes [pip](https://pip.pypa.io/en/stable/) para instalação do pacote '**processamento_de_imagem**':

```bash
pip install processamento_de_imagens
```

## Uso:

```python
from package_name.module1_name import file1_name
file1_name.my_function()
```

## Autor:
Esse Projeto: Gerdison

## License
[MIT](https://choosealicense.com/licenses/mit/)
